@@ -30,7 +30,7 @@ def resume_pdf(request):
     )
 
     if font:
-        font = space_to_plus(font).capitalize()
+        font = space_to_plus(font).title()
         HTML(url=resume_url).write_pdf(
             response,
             stylesheets=[
